==> openshift-model-hive-5.12.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SyncSetSpecBuilder extends io.fabric8.openshift.api.model.hive.v1.SyncSetSpecFluentImpl<io.fabric8.openshift.api.model.hive.v1.SyncSetSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.SyncSetSpec,io.fabric8.openshift.api.model.hive.v1.SyncSetSpecBuilder>{
  public SyncSetSpecBuilder() {
    this(false);
  }
  public SyncSetSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new SyncSetSpec(), validationEnabled);
  }
  public SyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SyncSetSpec(), validationEnabled);
  }
  public SyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncSetSpec instance) {
    this(fluent, instance, false);
  }
  public SyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetSpecFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SyncSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplyBehavior(instance.getApplyBehavior()); 
    fluent.withClusterDeploymentRefs(instance.getClusterDeploymentRefs()); 
    fluent.withPatches(instance.getPatches()); 
    fluent.withResourceApplyMode(instance.getResourceApplyMode()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSecretMappings(instance.getSecretMappings()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetSpec instance) {
    this(instance,false);
  }
  public SyncSetSpecBuilder(io.fabric8.openshift.api.model.hive.v1.SyncSetSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplyBehavior(instance.getApplyBehavior()); 
    this.withClusterDeploymentRefs(instance.getClusterDeploymentRefs()); 
    this.withPatches(instance.getPatches()); 
    this.withResourceApplyMode(instance.getResourceApplyMode()); 
    this.withResources(instance.getResources()); 
    this.withSecretMappings(instance.getSecretMappings()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.SyncSetSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.SyncSetSpec build() {
    SyncSetSpec buildable = new SyncSetSpec(fluent.getApplyBehavior(),fluent.getClusterDeploymentRefs(),fluent.getPatches(),fluent.getResourceApplyMode(),fluent.getResources(),fluent.getSecretMappings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SyncSetSpecBuilder that = (SyncSetSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.4.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/SyncSetSpecBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SyncSetSpecBuilder extends SyncSetSpecFluentImpl<SyncSetSpecBuilder> implements VisitableBuilder<SyncSetSpec,SyncSetSpecBuilder>{
  public SyncSetSpecBuilder() {
    this(false);
  }
  public SyncSetSpecBuilder(Boolean validationEnabled) {
    this(new SyncSetSpec(), validationEnabled);
  }
  public SyncSetSpecBuilder(SyncSetSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public SyncSetSpecBuilder(SyncSetSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SyncSetSpec(), validationEnabled);
  }
  public SyncSetSpecBuilder(SyncSetSpecFluent<?> fluent,SyncSetSpec instance) {
    this(fluent, instance, false);
  }
  public SyncSetSpecBuilder(SyncSetSpecFluent<?> fluent,SyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApplyBehavior(instance.getApplyBehavior()); 
    fluent.withClusterDeploymentRefs(instance.getClusterDeploymentRefs()); 
    fluent.withPatches(instance.getPatches()); 
    fluent.withResourceApplyMode(instance.getResourceApplyMode()); 
    fluent.withResources(instance.getResources()); 
    fluent.withSecretMappings(instance.getSecretMappings()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SyncSetSpecBuilder(SyncSetSpec instance) {
    this(instance,false);
  }
  public SyncSetSpecBuilder(SyncSetSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApplyBehavior(instance.getApplyBehavior()); 
    this.withClusterDeploymentRefs(instance.getClusterDeploymentRefs()); 
    this.withPatches(instance.getPatches()); 
    this.withResourceApplyMode(instance.getResourceApplyMode()); 
    this.withResources(instance.getResources()); 
    this.withSecretMappings(instance.getSecretMappings()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SyncSetSpecFluent<?> fluent;
  Boolean validationEnabled;
  public SyncSetSpec build() {
    SyncSetSpec buildable = new SyncSetSpec(fluent.getApplyBehavior(),fluent.getClusterDeploymentRefs(),fluent.getPatches(),fluent.getResourceApplyMode(),fluent.getResources(),fluent.getSecretMappings());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
